package com.dskj.znzn.importData.common.utils;

import org.mozilla.universalchardet.UniversalDetector;

import java.io.*;
import java.nio.charset.StandardCharsets;
import java.nio.file.Files;
import java.nio.file.Paths;

public class FileEncodingConverter {

    /**
     * 检测文件的编码
     *
     * @param fis 文件流
     * @return 检测到的编码
     * @throws IOException 如果读取文件时发生错误
     */
    public static String detectFileCharset(InputStream fis) throws IOException {
        byte[] buf = new byte[4096];
        UniversalDetector detector = new UniversalDetector(null);

        int nRead;
        while ((nRead = fis.read(buf)) > 0 && !detector.isDone()) {
            detector.handleData(buf, 0, nRead);
        }
        detector.dataEnd();

        String detectedCharset = detector.getDetectedCharset();
        detector.reset();
        fis.reset();

        if (null == detectedCharset) {
            return "GB18030";
        }

        return detectedCharset;
    }

    /**
     * 转化文件到 InputStream流
     *
     * @param fileName 文件名
     */
    public static InputStream convertFileToInputStream(String fileName) throws IOException {
        return convertFileToInputStream(Files.newInputStream(Paths.get(fileName)));
    }

    public static byte[] getInputByte(InputStream inputStream) throws IOException {
        // 将 InputStream 内容读取到字节数组中
        ByteArrayOutputStream baos = new ByteArrayOutputStream();
        byte[] buffer = new byte[1024];
        int len;
        while ((len = inputStream.read(buffer)) != -1) {
            baos.write(buffer, 0, len);
        }
        inputStream.close();

        return baos.toByteArray();
    }

    public static InputStream convertFileToInputStream(InputStream inputStream) throws IOException {

        // 使用 ByteArrayInputStream 多次读取
        byte[] byteArrays = getInputByte(inputStream);

        InputStream inputStream1 = new ByteArrayInputStream(byteArrays);
        InputStream inputStream2 = new ByteArrayInputStream(byteArrays);

        String detectedCharset = detectFileCharset(inputStream1);
        System.out.println(" 文件编码: " + detectedCharset);
        if (StandardCharsets.UTF_8.displayName().equalsIgnoreCase(detectedCharset)) {
            return inputStream1;
        } else {
            try (InputStreamReader reader = new InputStreamReader(inputStream2, detectedCharset);
                 ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream()) {

                // 将 InputStreamReader 读取的字符数据转换为字节数据并写入 ByteArrayOutputStream
                char[] buffer = new char[1024];
                int len;
                while ((len = reader.read(buffer)) != -1) {
                    byte[] bytes = new String(buffer, 0, len).getBytes(StandardCharsets.UTF_8);
                    byteArrayOutputStream.write(bytes);
                }

                return new ByteArrayInputStream(byteArrayOutputStream.toByteArray());
            }
        }
    }

    /**
     * 将文件转换为 UTF-8 编码
     *
     * @param inputFileName  输入文件路径
     * @param outputFileName 输出文件路径
     * @param sourceCharset  源文件的编码
     * @throws IOException 如果读取或写入文件时发生错误
     */
    public static void convertFileToUtf8(String inputFileName, String outputFileName, String sourceCharset) throws
            IOException {
        try (InputStream inputStream = Files.newInputStream(Paths.get(inputFileName));
             InputStreamReader reader = new InputStreamReader(inputStream, sourceCharset);
             BufferedReader bufferedReader = new BufferedReader(reader);
             OutputStream outputStream = Files.newOutputStream(Paths.get(outputFileName));
             OutputStreamWriter writer = new OutputStreamWriter(outputStream, StandardCharsets.UTF_8);
             BufferedWriter bufferedWriter = new BufferedWriter(writer)) {

            String line;
            while ((line = bufferedReader.readLine()) != null) {
                bufferedWriter.write(line);
                bufferedWriter.newLine();
            }
        }
    }

    public static void main(String[] args) throws IOException {

        InputStream inputStream = Files.newInputStream(new File("D:\\data\\b2_240828_2324_Err.csv").toPath());
        System.out.println(detectFileCharset(inputStream));

    }
}