package com.dskj.znzn.importData.web.controller;

import com.dskj.znzn.importData.common.base.R;
import com.dskj.znzn.importData.web.entity.BaseTemplate;
import com.dskj.znzn.importData.web.indata.AddBaseTemplateInData;
import com.dskj.znzn.importData.web.indata.EditBaseTemplateInData;
import com.dskj.znzn.importData.web.outdata.GetBaseTemplateOutData;
import com.dskj.znzn.importData.web.service.IBaseTemplateService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;


/**
 * @author 魏志亮
 * @since 2024-10-30
 */
@RestController
@RequestMapping("baseTemplate")
@RequiredArgsConstructor(onConstructor = @__({@Autowired}))
@Api(tags = "基础模板")
public class BaseTemplateController {

    private final IBaseTemplateService baseTemplateService;

    @ApiOperation(value = "根据模板ID获取")
    @GetMapping("/get/{id}")
    public R<GetBaseTemplateOutData> getBaseDataById(@PathVariable Integer id) {
        return R.ok(baseTemplateService.getBaseDataById(id));
    }

    @ApiOperation(value = "获取所有模板")
    @GetMapping("getAllEnabled")
    public R<List<BaseTemplate>> getAllEnabled(String name) {
        return R.ok(baseTemplateService.getAllEnabled(name));
    }

    @ApiOperation(value = "添加模板")
    @PostMapping("addTemplate")
    public R addTemplate(@Validated @RequestBody AddBaseTemplateInData inData) {
        baseTemplateService.addTemplate(inData);
        return R.ok();
    }

    @ApiOperation(value = "删除模板")
    @PostMapping("/del/{id}")
    public R deleteTemplate(@PathVariable Integer id) {
        baseTemplateService.deleteTemplate(id);
        return R.ok();
    }

    @ApiOperation(value = "编辑模板")
    @PostMapping("editTemplate")
    public R editTemplate(@Valid @RequestBody EditBaseTemplateInData inData) {
        baseTemplateService.editTemplate(inData);
        return R.ok();
    }

    @ApiOperation(value = "查询模板是否已被使用")
    @GetMapping("/queryUsed/{id}")
    public R queryUsed(@PathVariable Integer id) {
        baseTemplateService.queryUsed(id);
        return R.ok();
    }

//    @ApiOperation(value = "复制模板")
//    @GetMapping("/copyTemplate/{id}")
//    public R copyTemplate(@PathVariable Integer id) {
//        baseTemplateService.copyTemplate(id);
//        return R.ok();
//    }
}
