package com.dskj.znzn.importData.web.controller;

import com.dskj.znzn.importData.common.base.R;
import com.dskj.znzn.importData.common.exception.BusinessException;
import com.dskj.znzn.importData.web.entity.ProcessExecutor;
import com.dskj.znzn.importData.web.indata.ReadExcepDataInData;
import com.dskj.znzn.importData.web.outdata.ProcessExecutorOutData;
import com.dskj.znzn.importData.web.outdata.ReadExcelDataOutData;
import com.dskj.znzn.importData.web.service.IProcessExecutorService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.Arrays;
import java.util.List;
import java.util.Locale;


/**
 * @author 魏志亮
 * @since 2024-10-30
 */
@RestController
@RequestMapping("processExecutor")
@RequiredArgsConstructor(onConstructor = @__({@Autowired}))
@Api(tags = "执行器")
public class ProcessExecutorController {

    private final IProcessExecutorService processService;

    @ApiOperation(value = "根据执行器组ID获取所有执行器参数")
    @GetMapping("/getByProcessGroupId/{processGroupId}")
    public R<List<ProcessExecutor>> getByProcessGroupId(@PathVariable Integer processGroupId) {
        return R.ok(processService.getByProcessGroupId(processGroupId));
    }

    @ApiOperation(value = "根据执行器组ID获取所有执行器完整信息")
    @GetMapping("/getCompleteByProcessGroupId/{processGroupId}")
    public R<List<ProcessExecutorOutData>> getCompleteByProcessGroupId(@PathVariable Integer processGroupId) {
        return R.ok(processService.getCompleteByProcessGroupId(processGroupId));
    }


    @ApiOperation(value = "读取excel数据")
    @PostMapping("readExcelData")
    @ApiImplicitParam(name = "file", value = "文件", required = true, dataType = "file", paramType = "query")
    public R<ReadExcelDataOutData> readExcelData(@RequestParam("file") MultipartFile[] files, ReadExcepDataInData inData) throws Exception {

        if (null == files || files.length == 0) {
            throw new BusinessException("文件不能为空");
        }
        MultipartFile file = files[0];
        if (file.isEmpty()) {
            throw new BusinessException("文件不能为空");
        }

        String fileName = file.getOriginalFilename();
        assert fileName != null;
        String suffix = fileName.substring(fileName.lastIndexOf(".") + 1).toLowerCase(Locale.ROOT);
        System.out.println("文件名:" + fileName);
        System.out.println("文件后缀:" + suffix);
        List<String> suffixList = Arrays.asList("xls", "xlsx", "csv");
        if (!suffixList.contains(suffix)) {
            throw new BusinessException("文件格式不支持,当前支持:" + String.join(",", suffixList));
        }
        ReadExcelDataOutData outData = new ReadExcelDataOutData(processService.readExcelData(fileName, file.getInputStream(), suffix, inData));
        return R.ok(outData);
    }

}
