package com.dskj.znzn.importData.web.controller;

import com.dskj.znzn.importData.common.base.R;
import com.dskj.znzn.importData.web.entity.ProcessGroup;
import com.dskj.znzn.importData.web.indata.AddProcessGroupInData;
import com.dskj.znzn.importData.web.indata.EditProcessGroupInData;
import com.dskj.znzn.importData.web.indata.SubmitProcessGroupInData;
import com.dskj.znzn.importData.web.service.IProcessGroupService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;


/**
 * @author 魏志亮
 * @since 2024-10-30
 */
@RestController
@RequestMapping("processGroup")
@RequiredArgsConstructor(onConstructor = @__({@Autowired}))
@Api(tags = "执行器组")
public class ProcessGroupController {

    private final IProcessGroupService processGroupService;

    @ApiOperation(value = "根据模板ID获取")
    @GetMapping("/template/{templateId}")
    public R<List<ProcessGroup>> getByTemplateId(@PathVariable Integer templateId) {
        return R.ok(processGroupService.getByTemplateId(templateId));
    }

    @PostMapping(value = "addProcessGroup")
    @ApiOperation(value = "添加执行器组")
    public R addProcessGroup(@Valid @RequestBody AddProcessGroupInData inData) {
        processGroupService.saveProceeGroup(inData);
        return R.ok();
    }

    @GetMapping(value = "/deleteProcessGroup/{processGroupId}")
    @ApiOperation(value = "删除执行器组")
    public R deleteProcessGroup(@PathVariable Integer processGroupId) {
        processGroupService.deleteProcessGroup(processGroupId);
        return R.ok();
    }

    @PostMapping(value = "editProcessGroup")
    @ApiOperation(value = "编辑执行器组")
    public R editProcessGroup(@Valid @RequestBody EditProcessGroupInData inData) {
        processGroupService.editProcessGroup(inData);
        return R.ok();
    }

    @GetMapping(value = "/copyProcessGroup/{processGroupId}")
    @ApiOperation(value = "复制执行器组")
    public R copyProcessGroup(@PathVariable Integer processGroupId) {
        processGroupService.copyProcessGroup(processGroupId);
        return R.ok();
    }

}
