package com.dskj.znzn.importData.web.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.dskj.znzn.importData.web.entity.BaseTemplateField;
import com.dskj.znzn.importData.web.indata.TemplateFieldsInData;
import com.dskj.znzn.importData.web.mapper.BaseTemplateFieldMapper;
import com.dskj.znzn.importData.web.service.IBaseTemplateFieldService;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author 魏志亮
 * @since 2024-10-29
 */
@Service
@RequiredArgsConstructor(onConstructor = @__({@Autowired}))
public class BaseTemplateFieldServiceImpl extends ServiceImpl<BaseTemplateFieldMapper, BaseTemplateField> implements IBaseTemplateFieldService {

    private final BaseTemplateFieldMapper baseTemplateFieldMapper;

    @Override
    public List<BaseTemplateField> getByTemplateId(Integer templateId) {
        LambdaQueryWrapper<BaseTemplateField> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(BaseTemplateField::getTemplateId, templateId);
        return list(queryWrapper);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void deleteAndSaveByTemplateId(Integer id, List<TemplateFieldsInData> templateFieldsInDataList) {
        baseTemplateFieldMapper.deleteByTemplateId(id);
        List<BaseTemplateField> fieldsList = new ArrayList<>();
        for (TemplateFieldsInData fields : templateFieldsInDataList) {
            BaseTemplateField baseTemplateField = new BaseTemplateField();
            baseTemplateField.setTemplateId(id);
            baseTemplateField.setStandardizedName(fields.getStandardizedName());
            baseTemplateField.setIsIndex(fields.getIsIndex());
            baseTemplateField.setIsCutCol(fields.getIsCutCol());
            fieldsList.add(baseTemplateField);
        }
        saveBatch(fieldsList, 100);
    }
}
