package com.dskj.znzn.importData.web.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.dskj.znzn.importData.common.base.PageR;
import com.dskj.znzn.importData.web.entity.ExecutorHistory;
import com.dskj.znzn.importData.web.indata.ExecutorHistoryProcessInData;
import com.dskj.znzn.importData.web.indata.ListByQueryInData;
import com.dskj.znzn.importData.web.indata.SubmitProcessGroupInData;
import com.dskj.znzn.importData.web.mapper.ExecutorHistoryMapper;
import com.dskj.znzn.importData.web.outdata.ExecutorHistoryOutData;
import com.dskj.znzn.importData.web.service.IExecutorHistoryService;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author 魏志亮
 * @since 2024-11-25
 */
@Service
@RequiredArgsConstructor(onConstructor = @__({@Autowired}))
public class ExecutorHistoryServiceImpl extends ServiceImpl<ExecutorHistoryMapper, ExecutorHistory> implements IExecutorHistoryService {

    private final ExecutorHistoryMapper executorHistoryMapper;

    @Override
    public void submitProcessGroup(SubmitProcessGroupInData inData) {

        ExecutorHistory history = new ExecutorHistory();
        history.setName(inData.getName());
        history.setProcessGroupId(inData.getProcessGroupId());
        history.setInputDirs(JSON.toJSONString(inData.getExecutorHistoryProcessInDataList()));
        history.setOutPutDir(inData.getOutputDir());
        history.setExecStatus(-1);
        save(history);
    }

    @Override
    public PageR<ExecutorHistoryOutData> listByQuery(ListByQueryInData inData) {
        Page<ExecutorHistoryOutData> page = Page.of(inData.getPageNo(), inData.getPageSize());
        IPage<ExecutorHistoryOutData> pageInfo = executorHistoryMapper.listByQuery(page, inData);
        List<ExecutorHistoryOutData> datas = pageInfo.getRecords();
        for (ExecutorHistoryOutData outData : datas) {
            String inputDirs = outData.getInputDirs();
            outData.setProcessExecutorList(JSON.parseArray(inputDirs, ExecutorHistoryProcessInData.class));
        }

        return PageR.page(pageInfo);
    }
}
