package com.dskj.znzn.importData.web.service.impl;

import com.alibaba.excel.EasyExcel;
import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.event.AnalysisEventListener;
import com.alibaba.excel.support.ExcelTypeEnum;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.dskj.znzn.importData.web.entity.ProcessExecutor;
import com.dskj.znzn.importData.web.outdata.ProcessExecutorOutData;
import com.dskj.znzn.importData.web.indata.ReadExcepDataInData;
import com.dskj.znzn.importData.web.mapper.ProcessExecutorMapper;
import com.dskj.znzn.importData.web.service.IMappingFieldService;
import com.dskj.znzn.importData.web.service.IProcessExecutorService;
import lombok.RequiredArgsConstructor;
import lombok.SneakyThrows;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.io.IOException;
import java.io.InputStream;
import java.util.*;
import java.util.stream.Collectors;

import static com.dskj.znzn.importData.common.utils.FileEncodingConverter.convertFileToInputStream;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author 魏志亮
 * @since 2024-10-29
 */
@Service
@RequiredArgsConstructor(onConstructor = @__({@Autowired}))
public class ProcessExecutorServiceImpl extends ServiceImpl<ProcessExecutorMapper, ProcessExecutor> implements IProcessExecutorService {

    private final IMappingFieldService mappingFieldService;

    @Override
    public List<ProcessExecutor> getByProcessGroupId(Integer processGroupId) {
        LambdaQueryWrapper<ProcessExecutor> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(ProcessExecutor::getGroupId, processGroupId)
                .eq(ProcessExecutor::getStatus, 1);
        return list(queryWrapper);
    }

    @Override
    public List<Map<Integer, Object>> readExcelData(String fileName, InputStream inputStream, String suffix, ReadExcepDataInData inData) throws IOException {
        List<Map<Integer, Object>> data = new ArrayList<>();

        if ("csv".equals(suffix)) {
            inputStream = convertFileToInputStream(inputStream);
        }

        EasyExcel.read(inputStream, new AnalysisEventListener<Map<Integer, Object>>() {

            @SneakyThrows
            @Override
            public void invoke(Map<Integer, Object> obj, AnalysisContext context) {
                int nowIndex = context.readRowHolder().getRowIndex();
                System.out.println("当前行数" + context.readRowHolder().getRowIndex());
                if (nowIndex >= inData.getMinRowNum() - 1) {
                    if (null != inData.getReadRowNum()) {
                        if (inData.getReadRowNum().equals(context.readRowHolder().getRowIndex() + 1)) {
                            for (Integer key : obj.keySet()) {
                                obj.computeIfAbsent(key, k -> "缺失列名" + k);
                            }
                            data.add(obj);
                        }
                    } else {
                        for (Integer key : obj.keySet()) {
                            obj.computeIfAbsent(key, k -> "缺失列名" + (k + 1));
                        }
                        data.add(obj);
                    }
                }
                System.out.println("当前行数小于开始行数" + inData.getMinRowNum() + "已跳过");
            }

            @Override
            public boolean hasNext(AnalysisContext context) {
                if (context.readRowHolder().getRowIndex() >= inData.getMaxRowNum() - 1) {
                    return false;
                }

                if (null != inData.getReadRowNum() && context.readRowHolder().getRowIndex() > inData.getReadRowNum() - 1) {
                    return false;
                }

                return super.hasNext(context);
            }

            @Override
            public void doAfterAllAnalysed(AnalysisContext context) {

            }
        }).excelType(getExcelType(suffix)).sheet().headRowNumber(0).doRead();

        if (inData.getHasColName() == 0) {
            Set<Integer> keys = data.stream().map(Map::keySet).flatMap(Collection::stream).collect(Collectors.toSet());
            Map<Integer, Object> obj = new LinkedHashMap<>(keys.size());
            for (Integer key : keys) {
                obj.computeIfAbsent(key, k -> "无列名" + (k + 1));
            }
            data.add(0, obj);
        }

        return data;
    }

    private ExcelTypeEnum getExcelType(String suffix) {
        suffix = suffix.toLowerCase();
        ExcelTypeEnum excelTypeEnum = null;
        switch (suffix) {
            case "csv":
                excelTypeEnum = ExcelTypeEnum.CSV;
                break;
            case "xls":
                excelTypeEnum = ExcelTypeEnum.XLS;
                break;
            case "xlsx":
                excelTypeEnum = ExcelTypeEnum.XLSX;
                break;
        }
        if (excelTypeEnum != null) {
            System.out.println(excelTypeEnum.getValue());
        }
        return excelTypeEnum;
    }

    @Override
    public List<ProcessExecutorOutData> getCompleteByProcessGroupId(Integer processGroupId) {
        LambdaQueryWrapper<ProcessExecutor> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(ProcessExecutor::getGroupId, processGroupId)
                .eq(ProcessExecutor::getStatus, 1);
        List<ProcessExecutorOutData> outDataList = new ArrayList<>();
        for (ProcessExecutor processExecutor : list(queryWrapper)) {
            ProcessExecutorOutData outData = new ProcessExecutorOutData();
            outData.setId(processExecutor.getId());
            outData.setName(processExecutor.getName());
            outData.setGroupId(processExecutor.getGroupId());
            outData.setKnownFields(processExecutor.getKnownFields());
            outData.setMappingFieldList(mappingFieldService.getByProcessId(processExecutor.getId()));
            outDataList.add(outData);
        }

        return outDataList;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void deleteByProcessGroupId(Integer id) {

        List<Integer> ids = getByProcessGroupId(id).stream().map(ProcessExecutor::getId).collect(Collectors.toList());

        List<ProcessExecutor> updateList = new ArrayList<>();
        for (Integer executorId : ids) {
            ProcessExecutor executor = new ProcessExecutor();
            executor.setId(executorId);
            executor.setStatus(0);
            updateList.add(executor);
        }
        updateBatchById(updateList);
    }
}
